#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.reference.location.interfaces.region import IRegionTable, IRegion
from pyams_i18n.interfaces import II18n
from zope.component.interfaces import ISite
from zope.lifecycleevent.interfaces import IObjectAddedEvent

# import packages
from onf_website.reference import ReferenceInfo
from onf_website.reference import ReferenceTable
from pyams_utils.registry import query_utility
from pyams_utils.request import check_request
from pyams_utils.traversing import get_parent
from pyramid.events import subscriber
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty
from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm, getVocabularyRegistry


@implementer(IRegionTable)
class RegionTable(ReferenceTable):
    """Regions table"""


@subscriber(IObjectAddedEvent, context_selector=IRegionTable)
def handle_added_region_table(event):
    """Handle new region table"""
    site = get_parent(event.object, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, IRegionTable)


@implementer(IRegion)
class Region(ReferenceInfo):
    """Region record"""

    localization_title = FieldProperty(IRegion['localization_title'])
    appropriation_table = FieldProperty(IRegion['appropriation_title'])
    insee_code = FieldProperty(IRegion['insee_code'])
    territory = FieldProperty(IRegion['territory'])
    departments = FieldProperty(IRegion['departments'])
    neighbors = FieldProperty(IRegion['neighbors'])


class RegionVocabulary(SimpleVocabulary):
    """Regions vocabulary"""

    def __init__(self, context=None):
        table = query_utility(IRegionTable)
        if table is not None:
            request = check_request()
            terms = [SimpleTerm(v, title=II18n(v).query_attribute('title', request=request))
                     for v in table.values()]
        else:
            terms = []
        super(RegionVocabulary, self).__init__(terms)

getVocabularyRegistry().register('ONF regions', RegionVocabulary)
