#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.reference.interfaces import IReferenceManager, IReferenceInfo
from pyams_content.interfaces import MANAGE_SITE_ROOT_PERMISSION
from pyams_i18n.interfaces import II18n
from pyams_skin.interfaces.container import ITableElementName
from pyams_skin.interfaces.viewlet import ITopLinksViewletManager
from pyams_zmi.layer import IAdminLayer

# import packages
from pyams_skin.viewlet.toplinks import TopLinksViewlet, TopLinksMenu
from pyams_utils.adapter import adapter_config, ContextRequestAdapter
from pyams_utils.registry import get_local_registry
from pyams_utils.url import absolute_url
from pyams_viewlet.viewlet import viewlet_config
from zope.interface import Interface

from onf_website import _


@viewlet_config(name='references.menu', layer=IAdminLayer, manager=ITopLinksViewletManager,
                permission=MANAGE_SITE_ROOT_PERMISSION, weight=70)
class ReferencesMenu(TopLinksViewlet):
    """References tables menu"""

    label = ''
    css_class = 'top-menu bordered margin-top-10'
    dropdown_label = _("References")

    def update(self):
        super(ReferencesMenu, self).update()
        registry = get_local_registry()
        references = registry.queryUtility(IReferenceManager)
        if references is not None:
            for table in references.values():
                menu = TopLinksMenu(self.context, self.request, self.__parent__, self)
                menu.label = II18n(table).query_attribute('short_name', request=self.request) or table.__name__
                menu.url = absolute_url(table, self.request, 'admin.html#contents.html')
                self.viewlets.append(menu)


@adapter_config(context=(IReferenceInfo, Interface), provides=ITableElementName)
class ReferenceInfoTableElementName(ContextRequestAdapter):
    """Reference table element name"""

    @property
    def name(self):
        return II18n(self.context).query_attribute('title', request=self.request)
